sconce.trainers package — Pytorch-Sconce master documentation

# sconce.trainers package

## sconce.trainers.autoencoder_trainer module

class `sconce.trainers.autoencoder_trainer.` `AutoencoderMixin`

  Bases: `abc.ABC`

  `plot_input_output_pairs`(title='A Sampling of Autoencoder Results', num_cols=10, figsize=(15, 3.2))
  `plot_latent_space`(title='Latent Representation', figsize=(8, 8))

class `sconce.trainers.autoencoder_trainer.` `AutoencoderTrainer`(*, model, training_data_generator, test_data_generator, optimizer, monitor=None, rate_controller=None)

  Bases: `sconce.trainer.Trainer`, `sconce.trainers.autoencoder_trainer.AutoencoderMixin`

## sconce.trainers.classifier_trainer module

class `sconce.trainers.classifier_trainer.` `ClassifierMixin`

  Bases: `abc.ABC`

  `get_classification_accuracy`(data_generator=None, cache_results=True)
  `get_confusion_matrix`(data_generator=None, cache_results=True)
  `plot_confusion_matrix`(data_generator=None, **heatmap_kwargs)
  `plot_samples`(predicted_label, true_label=None, data_generator=None, sort_by='rising predicted label score', num_samples=7, num_cols=7, figure_width=15, image_height=3, cache_results=True)

class `sconce.trainers.classifier_trainer.` `ClassifierTrainer`(*, model, training_data_generator, test_data_generator, optimizer, monitor=None, rate_controller=None)

  Bases: `sconce.trainer.Trainer`, `sconce.trainers.classifier_trainer.ClassifierMixin`